nnsight.intervention
--------------------

.. automodule:: nnsight.intervention
   :members:

.. automodule:: nnsight.intervention.protocols
   :members:

.. automodule:: nnsight.intervention.protocols.entrypoint
   :members:

.. automodule:: nnsight.intervention.protocols.grad
   :members:

.. automodule:: nnsight.intervention.protocols.intervention
   :members:

.. automodule:: nnsight.intervention.protocols.module
   :members:

.. automodule:: nnsight.intervention.protocols.swap
   :members:

.. automodule:: nnsight.intervention.contexts
   :members:

.. automodule:: nnsight.intervention.contexts.editing
   :members:

.. automodule:: nnsight.intervention.contexts.globals
   :members:

.. automodule:: nnsight.intervention.contexts.interleaving
   :members:

.. automodule:: nnsight.intervention.contexts.invoker
   :members:

.. automodule:: nnsight.intervention.contexts.local
   :members:

.. automodule:: nnsight.intervention.contexts.session
   :members:

.. automodule:: nnsight.intervention.contexts.tracer
   :members:

.. automodule:: nnsight.intervention.backends
   :members:

.. automodule:: nnsight.intervention.backends.editing
   :members:

.. automodule:: nnsight.intervention.backends.remote
   :members:

.. automodule:: nnsight.intervention.graph
   :members:

.. automodule:: nnsight.intervention.graph.graph
   :members:

.. automodule:: nnsight.intervention.graph.node
   :members:

.. automodule:: nnsight.intervention.graph.proxy
   :members:

.. automodule:: nnsight.intervention.base
   :members:

.. automodule:: nnsight.intervention.envoy
   :members:

.. automodule:: nnsight.intervention.interleaver
   :members: